==> thucydides-easyb-plugin-0.9.102-sources.jar: net/thucydides/easyb/PluginConfiguration.java <==
package net.thucydides.easyb;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class PluginConfiguration
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getStoryClass() { return null;}
public  void setStoryClass(java.lang.Object value) { }
public  java.lang.Object getRegisteredSteps() { return null;}
public  void setRegisteredSteps(java.lang.Object value) { }
public  java.lang.Object getStepNameMap() { return null;}
public  void setStepNameMap(java.lang.Object value) { }
public  void setScenarioIssues(java.lang.Object value) { }
public  java.lang.Object getTags() { return null;}
public  void setTags(java.lang.Object value) { }
public  java.lang.Object getResetBrowserInEachScenario() { return null;}
public  void setResetBrowserInEachScenario(java.lang.Object value) { }
public  java.lang.Object getRequestedDriver() { return null;}
public  void setRequestedDriver(java.lang.Object value) { }
public static synchronized  java.lang.Object reset() { return null;}
public static synchronized  net.thucydides.easyb.PluginConfiguration getInstance() { return (net.thucydides.easyb.PluginConfiguration)null;}
public  void uses_default_base_url(java.lang.String defaultBaseUrl) { }
public  void use_mock_driver(org.openqa.selenium.WebDriver webDriver) { }
public  void stop_using_mock_driver() { }
public  void uses_steps_from(java.lang.Class<net.thucydides.core.steps.ScenarioSteps> stepsClass) { }
public  void uses_steps_from(java.lang.Class<net.thucydides.core.steps.ScenarioSteps> stepsClass, java.lang.String stepName) { }
public  net.thucydides.easyb.PluginConfiguration.StepBuilder uses_steps_named(java.lang.String stepName) { return (net.thucydides.easyb.PluginConfiguration.StepBuilder)null;}
public  net.thucydides.easyb.Tagger getTests() { return (net.thucydides.easyb.Tagger)null;}
public  net.thucydides.easyb.Tagger getTesting() { return (net.thucydides.easyb.Tagger)null;}
public  void tests_issue(java.lang.String issue) { }
public  void tests_issues(java.lang.String... issues) { }
public  void tests_feature(java.lang.String featureName) { }
public  void tests_story(java.lang.String storyName) { }
public  void tag(java.lang.String name, java.lang.Object type) { }
public  java.util.List<java.lang.String> getScenarioIssues() { return (java.util.List<java.lang.String>)null;}
public  void tests_story(java.lang.Class<?> story) { }
public  void setDefaultBaseUrl(java.lang.String defaultBaseUrl) { }
public  java.lang.String getDefaultBaseUrl() { return (java.lang.String)null;}
public  void use_new_broswer_for_each_scenario() { }
public  void use_unique_browser_session() { }
public  boolean isResetBrowserInEachScenario() { return false;}
public  void uses_driver(java.lang.String driver) { }
public  java.lang.Object clearTags() { return null;}
public  java.lang.Object clearIssues() { return null;}
public  java.lang.String stepLibraryNameFor(java.lang.String stepLibraryClassName) { return (java.lang.String)null;}
public class StepBuilder
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getName() { return null;}
public  void setName(java.lang.Object value) { }
public  java.lang.Object from(java.lang.Class<net.thucydides.core.steps.ScenarioSteps> stepsClass) { return null;}
}
}

==> thucydides-easyb-plugin-0.9.224-sources.jar: net/thucydides/easyb/PluginConfiguration.java <==
package net.thucydides.easyb;

import java.lang.*;
import java.io.*;
import java.net.*;
import java.util.*;
import groovy.lang.*;
import groovy.util.*;

public class PluginConfiguration
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getStoryClass() { return null;}
public  void setStoryClass(java.lang.Object value) { }
public  java.lang.Object getRegisteredSteps() { return null;}
public  void setRegisteredSteps(java.lang.Object value) { }
public  java.lang.Object getStepNameMap() { return null;}
public  void setStepNameMap(java.lang.Object value) { }
public  void setScenarioIssues(java.lang.Object value) { }
public  java.lang.Object getTags() { return null;}
public  void setTags(java.lang.Object value) { }
public  java.lang.Object getResetBrowserInEachScenario() { return null;}
public  void setResetBrowserInEachScenario(java.lang.Object value) { }
public  java.lang.Object getRequestedDriver() { return null;}
public  void setRequestedDriver(java.lang.Object value) { }
public static synchronized  java.lang.Object reset() { return null;}
public static synchronized  net.thucydides.easyb.PluginConfiguration getInstance() { return (net.thucydides.easyb.PluginConfiguration)null;}
public  void uses_default_base_url(java.lang.String defaultBaseUrl) { }
public  void use_mock_driver(net.thucydides.core.webdriver.WebDriverFacade webDriver) { }
public  void stop_using_mock_driver() { }
public  void uses_steps_from(java.lang.Class<net.thucydides.core.steps.ScenarioSteps> stepsClass) { }
public  void uses_steps_from(java.lang.Class<net.thucydides.core.steps.ScenarioSteps> stepsClass, java.lang.String stepName) { }
public  net.thucydides.easyb.PluginConfiguration.StepBuilder uses_steps_named(java.lang.String stepName) { return (net.thucydides.easyb.PluginConfiguration.StepBuilder)null;}
public  net.thucydides.easyb.Tagger getTests() { return (net.thucydides.easyb.Tagger)null;}
public  net.thucydides.easyb.Tagger getTesting() { return (net.thucydides.easyb.Tagger)null;}
public  void tests_issue(java.lang.String issue) { }
public  void tests_issues(java.lang.String... issues) { }
public  void tests_feature(java.lang.String featureName) { }
public  void tests_story(java.lang.String storyName) { }
public  void tag(java.lang.String name, java.lang.Object type) { }
public  java.util.List<java.lang.String> getScenarioIssues() { return (java.util.List<java.lang.String>)null;}
public  void tests_story(java.lang.Class<?> story) { }
public  void setDefaultBaseUrl(java.lang.String defaultBaseUrl) { }
public  java.lang.String getDefaultBaseUrl() { return (java.lang.String)null;}
public  void use_new_broswer_for_each_scenario() { }
public  void use_unique_browser_session() { }
public  boolean isResetBrowserInEachScenario() { return false;}
public  void uses_driver(java.lang.String driver) { }
public  java.lang.Object clearTags() { return null;}
public  java.lang.Object clearIssues() { return null;}
public  java.lang.String stepLibraryNameFor(java.lang.String stepLibraryClassName) { return (java.lang.String)null;}
public class StepBuilder
  extends java.lang.Object  implements
    groovy.lang.GroovyObject {
public  groovy.lang.MetaClass getMetaClass() { return (groovy.lang.MetaClass)null;}
public  void setMetaClass(groovy.lang.MetaClass mc) { }
public  java.lang.Object invokeMethod(java.lang.String method, java.lang.Object arguments) { return null;}
public  java.lang.Object getProperty(java.lang.String property) { return null;}
public  void setProperty(java.lang.String property, java.lang.Object value) { }
public  java.lang.Object getName() { return null;}
public  void setName(java.lang.Object value) { }
public  java.lang.Object from(java.lang.Class<net.thucydides.core.steps.ScenarioSteps> stepsClass) { return null;}
}
}
